@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <list>
 #include <iterator>
 
-using namespace std;
+//using namespace std;
 
 namespace realob
 {
