@@ -18,7 +18,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. */
 
 
-using namespace std;
+//using namespace std;
 
 //	Deklaration der template-Klasse Array
 
