@@ -29,7 +29,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #include <iostream>
 
-using namespace std;
+//using namespace std;
 
 template <class T>
 class TreeNode
