@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -99,7 +99,8 @@ class __EXPORT_TYPE FC_linear  : public FC
   virtual void compute_XWX(datamatrix & r);
   virtual void compute_XWXroot(datamatrix & r);
   void compute_Wpartres(datamatrix & linpred);
-  double compute_XtWpartres(double & mo);
+//  void compute_Wpartres_multiplicative(datamatrix & linpred);
+//  double compute_XtWpartres(double & mo);
 
   void add_linpred(datamatrix & l);
 
