@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -156,9 +156,6 @@ class __EXPORT_TYPE MCMCsim
   //       'path' + title of the full conditional + "_sample.raw"
 
   void get_samples(ST::string & pathgraphs
-  #if defined(JAVA_OUTPUT_WINDOW)
-  , vector<ST::string> & newc
-  #endif
   );
 
   // DESTRUCTOR
